@@ -1,12 +1,12 @@
 from enum import Enum
-from typing import List, Dict
+from typing import List, Optional
 import logging
 
 import typer
 
 from .simulator import Simulator
 from .custom_exceptions import InvalidMovesException,  TimeoutException, MovesExceededException
-from .schema import PlayerMove, Player, GameResult, Position, Move, Piece
+from .schema import PlayerMove, Player, GameResult
 from .log_serializer import LogSerializer
 from .logger_utils import get_logger
 
@@ -34,7 +34,7 @@ def play_game(
     ),
     log_level: int = typer.Option(
         default=logging.WARNING, help="Logs level for simulator logs", show_default=True)
-) -> GameResult | None:
+) -> Optional[GameResult]:
     """
     Judge for the TU game. Enter the endpoints for bots
     let the judge play out the match
