@@ -1,6 +1,6 @@
 from pydoc import plain
 from time import sleep
-from typing import Any, List, Tuple
+from typing import Any, List, Optional, Tuple
 import logging
 
 import requests
@@ -42,7 +42,8 @@ class Simulator:
                     row_message += Fore.WHITE + cell + " "
             # row_message = Fore.RESET + Style.RESET_ALL
             self.visualizer.info(row_message)
-        self.visualizer.info(Fore.BLACK + Style.DIM + "==================================================")
+        self.visualizer.info(Fore.BLACK + Style.DIM +
+                             "==================================================")
         self.visualizer.info(Fore.RESET + Style.RESET_ALL)
 
     @staticmethod
@@ -73,11 +74,13 @@ class Simulator:
         InvalidMovesException
         """
         if self.board[move.dst.row][move.dst.col] != Piece.EMPTY_SPACE:
-            raise InvalidMovesException(reason=InvalidMovesMessage.INVALID_DESTINATION, player=player)
+            raise InvalidMovesException(
+                reason=InvalidMovesMessage.INVALID_DESTINATION, player=player)
         if (player == player.BLUE and self.board[move.src.row][move.src.col] not in self.BLUE_PIECES) or (
             player == player.RED and self.board[move.src.row][move.src.col] not in self.RED_PIECES
         ):
-            raise InvalidMovesException(reason=InvalidMovesMessage.INVALID_SOURCE, player=player)
+            raise InvalidMovesException(
+                reason=InvalidMovesMessage.INVALID_SOURCE, player=player)
         return None
 
     def validate_elimination_move(self, move: Move, player: Player) -> None:
@@ -97,7 +100,8 @@ class Simulator:
             return None
         else:
             print(f"{self.BLUE_PIECES}, {self.RED_PIECES}")
-            print(f"player {player}, elim_coords {eliminated_row, eliminated_col}, eliminated_piece: {eliminated_piece}")
+            print(
+                f"player {player}, elim_coords {eliminated_row, eliminated_col}, eliminated_piece: {eliminated_piece}")
             raise InvalidMovesException(
                 reason=InvalidMovesMessage.INVALID_ELIMINATION_TARGET, player=player)
 
@@ -175,7 +179,7 @@ class Simulator:
             eliminated_y_coord = int((move.src.col + move.dst.col) / 2)
             self.board[eliminated_x_coord][eliminated_y_coord] = Piece.EMPTY_SPACE
 
-    def check_if_game_over(self) -> Tuple[bool, Player | None]:
+    def check_if_game_over(self) -> Tuple[bool, Optional[Player]]:
         # RED BOMBER reaches blue home row
         if Piece.RED_BOMBER in self.board[0]:
             return True, Player.RED
@@ -189,18 +193,24 @@ class Simulator:
         self.logger.debug("Starting game simulation")
         self.print_board()
         while len(player_moves) < MAX_MOVES_ALLOWED:
-            bot_input = {"board": self.board, "data": bot_data[player], "player": player}
+            bot_input = {"board": self.board,
+                         "data": bot_data[player], "player": player}
 
-            response = requests.post(bot_urls[player], json=bot_input, timeout=self.move_timeout, headers={"Content-Type": "application/json"})
+            response = requests.post(
+                bot_urls[player], json=bot_input, timeout=self.move_timeout, headers={
+                    "Content-Type": "application/json"}
+            )
             if response.status_code != 200:
                 self.logger.error(
                     f"Invalid status code {response.status_code} received from player {player}. Expected: {200}")
-                raise InvalidMovesException(InvalidMovesMessage.INVALID_STATUS_CODE, player=player)
+                raise InvalidMovesException(
+                    InvalidMovesMessage.INVALID_STATUS_CODE, player=player)
 
             try:
                 bot_response = BotResponse.validate(response.json())
                 bot_data[player] = bot_response.data
-                player_moves.append(PlayerMove(move=bot_response.move, player=player))
+                player_moves.append(PlayerMove(
+                    move=bot_response.move, player=player))
 
                 self.validate_move(bot_response.move, player=player)
                 self.make_move(bot_response.move, player=player)
@@ -214,14 +224,18 @@ class Simulator:
                 else:
                     player = Player.BLUE
             except InvalidMovesException as imex:
-                self.logger.error(f"Invalid response received from player: {player}. Message: ", imex.message)
-                raise InvalidMovesException(reason=imex.reason, player=player)  # append player info to exception
+                self.logger.error(
+                    f"Invalid response received from player: {player}. Message: ", imex.message)
+                # append player info to exception
+                raise InvalidMovesException(reason=imex.reason, player=player)
             except Timeout as t:
                 self.logger.error(f"Request to player: {player} times out")
                 raise TimeoutException(player=player)
             except ValidationError as ve:
-                self.logger.error(f"Invalid response received from player: {player}. Message: ", str(ve))
-                raise InvalidMovesException(reason=f"Incorrect schema", player=player)
+                self.logger.error(
+                    f"Invalid response received from player: {player}. Message: ", str(ve))
+                raise InvalidMovesException(
+                    reason=f"Incorrect schema", player=player)
         raise MovesExceededException()
 
     def replay(self, player_moves: List[PlayerMove]):
@@ -240,8 +254,10 @@ class Simulator:
                     self.logger.info(f"Player {winner[1]} wins!")
                 sleep(1)
             except InvalidMovesException as ex:
-                self.logger.error(f"Invalid response received from player: {player}. Message: {ex.message}")
-                raise InvalidMovesException(reason=ex.reason, player=player)  # append player info to exception
+                self.logger.error(
+                    f"Invalid response received from player: {player}. Message: {ex.message}")
+                # append player info to exception
+                raise InvalidMovesException(reason=ex.reason, player=player)
 
     def play(self):
         self.print_board()
@@ -252,10 +268,12 @@ class Simulator:
         player = Player.BLUE
         while not self.check_if_game_over()[0]:
             prompt_color = Fore.BLUE if player == Player.BLUE else Fore.RED
-            input_string = input(prompt_color + f"Player {player}:\n" + Fore.RESET)
+            input_string = input(
+                prompt_color + f"Player {player}:\n" + Fore.RESET)
             try:
                 positions = [int(pos) for pos in input_string.split(" ")]
-                move = Move(src=Position(row=positions[0], col=positions[1]), dst=Position(row=positions[2], col=positions[3]))
+                move = Move(src=Position(row=positions[0], col=positions[1]), dst=Position(
+                    row=positions[2], col=positions[3]))
                 self.validate_move(move=move, player=player)
                 self.make_move(move=move, player=player)
                 self.print_board()
@@ -264,15 +282,20 @@ class Simulator:
                 else:
                     player = Player.BLUE
             except InvalidMovesException as ex:
-                self.visualizer.error(Fore.RED + Style.BRIGHT + f"Entered move was invalid. Reason: {str(ex)}")
-                self.visualizer.info(Fore.BLACK + Style.BRIGHT + f"Play again as player {player}")
+                self.visualizer.error(
+                    Fore.RED + Style.BRIGHT + f"Entered move was invalid. Reason: {str(ex)}")
+                self.visualizer.info(
+                    Fore.BLACK + Style.BRIGHT + f"Play again as player {player}")
                 self.print_board()
                 self.visualizer.info(Fore.RESET + Style.RESET_ALL)
             except Exception as ex:
-                self.visualizer.error(Fore.RED + Style.BRIGHT + f"Entered move format was incorrect. Play again as player {player}")
-                self.visualizer.info("Enter the inputs in the following format: <src row> <src col> <dst row> <dst col>")
+                self.visualizer.error(
+                    Fore.RED + Style.BRIGHT + f"Entered move format was incorrect. Play again as player {player}")
+                self.visualizer.info(
+                    "Enter the inputs in the following format: <src row> <src col> <dst row> <dst col>")
                 self.visualizer.info("Spaces matter!")
                 self.print_board()
         _, winner = self.check_if_game_over()
         prompt_color = Fore.BLUE if winner == Player.BLUE else Fore.RED
-        self.visualizer.info(prompt_color + f"Player {winner} wins!" + Fore.RESET)
+        self.visualizer.info(
+            prompt_color + f"Player {winner} wins!" + Fore.RESET)
